@@ -1,5 +1,7 @@
-//  Copyright (C) 2004-2025 Greg Landrum and other RDKit contributors
-
+// $Id$
+//
+//  Copyright (C) 2004-2010 Greg Landrum and Rational Discovery LLC
+//
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
 //  The contents are covered by the terms of the BSD license
@@ -7,7 +9,7 @@
 //  of the RDKit source tree.
 //
 
-#include <RDGeneral/test.h>
+#include <iostream>
 #include <RDGeneral/Invariant.h>
 #include <RDGeneral/RDLog.h>
 #include <RDGeneral/utils.h>
@@ -18,7 +20,6 @@
 #include <GraphMol/FileParsers/FileParsers.h>
 #include <GraphMol/FileParsers/MolSupplier.h>
 
-#include <GraphMol/ForceFieldHelpers/FFConvenience.h>
 #include <GraphMol/ForceFieldHelpers/MMFF/AtomTyper.h>
 #include <GraphMol/ForceFieldHelpers/MMFF/Builder.h>
 #include <GraphMol/ForceFieldHelpers/MMFF/MMFF.h>
@@ -26,6 +27,7 @@
 #include <ForceField/MMFF/Params.h>
 #include <GraphMol/DistGeomHelpers/Embedder.h>
 #include <GraphMol/Substruct/SubstructMatch.h>
+#include <boost/math/special_functions/round.hpp>
 
 using namespace RDKit;
 void testMMFFTyper1() {
@@ -33,7 +35,7 @@ void testMMFFTyper1() {
   BOOST_LOG(rdErrorLog) << "    Test MMFF atom types." << std::endl;
 
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("[SiH3]CC(=O)NC");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -53,7 +55,7 @@ void testMMFFTyper1() {
   }
 
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("CC(=O)C");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -71,7 +73,7 @@ void testMMFFTyper1() {
   }
 
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("C(=O)S");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -86,7 +88,7 @@ void testMMFFTyper1() {
     delete mol;
   }
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("SCS(=O)S(=O)(=O)O");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -103,7 +105,7 @@ void testMMFFTyper1() {
     delete mol;
   }
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("PCP(O)CP(=O)(=O)");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -120,7 +122,7 @@ void testMMFFTyper1() {
     delete mol;
   }
   {
-    std::uint8_t type;
+    boost::uint8_t type;
     ROMol *mol = SmilesToMol("C(F)(Cl)(Br)I");
     TEST_ASSERT(mol);
     MMFF::MMFFMolProperties mmffMolProperties(*mol);
@@ -149,10 +151,10 @@ void testMMFFBuilder1() {
   ROMol *mol, *mol2;
 
   ForceFields::ForceField *field;
-  boost::shared_array<std::uint8_t> nbrMat;
+  boost::shared_array<boost::uint8_t> nbrMat;
 
   mol = SmilesToMol("CC(O)C");
-  auto *conf = new Conformer(mol->getNumAtoms());
+  Conformer *conf = new Conformer(mol->getNumAtoms());
   int cid = static_cast<int>(mol->addConformer(conf, true));
   TEST_ASSERT(mol);
   MMFF::MMFFMolProperties *mmffMolProperties =
@@ -160,25 +162,11 @@ void testMMFFBuilder1() {
   TEST_ASSERT(mmffMolProperties);
   TEST_ASSERT(mmffMolProperties->isValid());
   field = new ForceFields::ForceField();
-  // add the atomic positions:f
-  for (unsigned int i = 0; i < mol->getNumAtoms(); ++i) {
-    field->positions().push_back(&(conf->getAtomPos(i)));
-  }
-
   MMFF::Tools::addBonds(*mol, mmffMolProperties, field);
 
-  TEST_ASSERT(field->contribs().size() == 1);
+  TEST_ASSERT(field->contribs().size() == 3);
 
   nbrMat = MMFF::Tools::buildNeighborMatrix(*mol);
-  // the neighbor matrix is an upper triangular matrix
-  // position indices are as follows:
-  //  0  1  2  3
-  //     4  5  6
-  //        7  8
-  //           9
-  TEST_ASSERT(MMFF::Tools::twoBitCellPos(mol->getNumAtoms(), 1, 1) == 4);
-  TEST_ASSERT(MMFF::Tools::twoBitCellPos(mol->getNumAtoms(), 2, 1) == 5);
-  TEST_ASSERT(MMFF::Tools::twoBitCellPos(mol->getNumAtoms(), 1, 2) == 5);
   TEST_ASSERT(MMFF::Tools::getTwoBitCell(nbrMat, 0) ==
               MMFF::Tools::RELATION_1_X);
   TEST_ASSERT(MMFF::Tools::getTwoBitCell(nbrMat, 1) ==
@@ -189,35 +177,30 @@ void testMMFFBuilder1() {
               MMFF::Tools::RELATION_1_3);
 
   MMFF::Tools::addAngles(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 6);
 
   // there are no non-bonded terms here:
   MMFF::Tools::addVdW(*mol, cid, mmffMolProperties, field, nbrMat);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 6);
 
   // and no torsions either, until we add Hs:
   MMFF::Tools::addTorsions(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 6);
 
   delete mol;
   delete field;
   delete mmffMolProperties;
   mol = SmilesToMol("CCOC");
-  auto *conf2 = new Conformer(mol->getNumAtoms());
+  Conformer *conf2 = new Conformer(mol->getNumAtoms());
   cid = static_cast<int>(mol->addConformer(conf2, true));
   TEST_ASSERT(mol);
   mmffMolProperties = new MMFF::MMFFMolProperties(*mol);
   TEST_ASSERT(mmffMolProperties);
   TEST_ASSERT(mmffMolProperties->isValid());
   field = new ForceFields::ForceField();
-  // add the atomic positions:
-  for (unsigned int i = 0; i < mol->getNumAtoms(); ++i) {
-    field->positions().push_back(&(conf2->getAtomPos(i)));
-  }
-
   MMFF::Tools::addBonds(*mol, mmffMolProperties, field);
 
-  TEST_ASSERT(field->contribs().size() == 1);
+  TEST_ASSERT(field->contribs().size() == 3);
 
   nbrMat = MMFF::Tools::buildNeighborMatrix(*mol);
   TEST_ASSERT(MMFF::Tools::getTwoBitCell(nbrMat, 0) ==
@@ -230,17 +213,17 @@ void testMMFFBuilder1() {
               MMFF::Tools::RELATION_1_4);
 
   MMFF::Tools::addAngles(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 5);
   MMFF::Tools::addVdW(*mol, cid, mmffMolProperties, field, nbrMat);
-  TEST_ASSERT(field->contribs().size() == 3);
+  TEST_ASSERT(field->contribs().size() == 6);
   MMFF::Tools::addTorsions(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 4);
+  TEST_ASSERT(field->contribs().size() == 7);
 
   delete mol;
   delete field;
   delete mmffMolProperties;
   mol = SmilesToMol("CO");
-  auto *conf3 = new Conformer(mol->getNumAtoms());
+  Conformer *conf3 = new Conformer(mol->getNumAtoms());
   cid = static_cast<int>(mol->addConformer(conf3, true));
   TEST_ASSERT(mol);
   mmffMolProperties = new MMFF::MMFFMolProperties(*mol);
@@ -248,11 +231,6 @@ void testMMFFBuilder1() {
   TEST_ASSERT(mmffMolProperties->isValid());
 
   field = new ForceFields::ForceField();
-  // add the atomic positions:
-  for (unsigned int i = 0; i < mol->getNumAtoms(); ++i) {
-    field->positions().push_back(&(conf3->getAtomPos(i)));
-  }
-
   MMFF::Tools::addBonds(*mol, mmffMolProperties, field);
 
   TEST_ASSERT(field->contribs().size() == 1);
@@ -272,9 +250,6 @@ void testMMFFBuilder1() {
 
   mol2 = MolOps::addHs(*mol);
   TEST_ASSERT(mol2->getNumAtoms() == 6);
-  auto *conf4 = new Conformer(mol2->getNumAtoms());
-  cid = static_cast<int>(mol2->addConformer(conf4, true));
-
   delete field;
   delete mmffMolProperties;
 
@@ -283,21 +258,16 @@ void testMMFFBuilder1() {
   TEST_ASSERT(mmffMolProperties->isValid());
 
   field = new ForceFields::ForceField();
-  // add the atomic positions:
-  for (unsigned int i = 0; i < mol2->getNumAtoms(); ++i) {
-    field->positions().push_back(&(conf4->getAtomPos(i)));
-  }
-
   MMFF::Tools::addBonds(*mol2, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 1);
+  TEST_ASSERT(field->contribs().size() == 5);
 
   nbrMat = MMFF::Tools::buildNeighborMatrix(*mol2);
   MMFF::Tools::addAngles(*mol2, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 12);
   MMFF::Tools::addVdW(*mol2, cid, mmffMolProperties, field, nbrMat);
-  TEST_ASSERT(field->contribs().size() == 3);
+  TEST_ASSERT(field->contribs().size() == 15);
   MMFF::Tools::addTorsions(*mol2, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 4);
+  TEST_ASSERT(field->contribs().size() == 18);
   delete mol2;
 
   delete mol;
@@ -387,10 +357,6 @@ void testMMFFBuilder2() {
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
 
-#ifdef RDK_TEST_MULTITHREADED
-// we do the equivalent tests below
-void testMMFFBatch() {}
-#else
 void testMMFFBatch() {
   BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
   BOOST_LOG(rdErrorLog)
@@ -415,27 +381,26 @@ void testMMFFBatch() {
     try {
       field = MMFF::constructForceField(*mol);
     } catch (...) {
-      field = nullptr;
+      field = 0;
     }
     if (field) {
       field->initialize();
       int failed = field->minimize(500);
-      delete field;
       if (failed) {
-        BOOST_LOG(rdErrorLog)
-            << " not converged (code = " << failed << ")" << std::endl;
+        BOOST_LOG(rdErrorLog) << " not converged (code = " << failed << ")"
+                              << std::endl;
         std::cout << origMolBlock << "$$$$" << std::endl;
         std::cout << MolToMolBlock(*mol) << "$$$$" << std::endl;
       }
+      delete field;
     }
     delete mol;
     mol = suppl.next();
   }
-  delete mol;
 
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
-#endif
+
 void testIssue239() {
   BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
   BOOST_LOG(rdErrorLog) << "    Testing Issue239." << std::endl;
@@ -467,104 +432,6 @@ void testIssue239() {
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
 
-void testCalcEnergyPassedCoords() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "    Testing calcEnergy with passed coords."
-                        << std::endl;
-
-  RWMol *mol;
-  ForceFields::ForceField *field;
-  double e1, e2, e3;
-
-  std::string pathName = getenv("RDBASE");
-  pathName += "/Code/GraphMol/ForceFieldHelpers/MMFF/test_data";
-  mol = MolFileToMol(pathName + "/Issue239.mol", false);
-  TEST_ASSERT(mol);
-  MolOps::sanitizeMol(*mol);
-
-  field = MMFF::constructForceField(*mol);
-  TEST_ASSERT(field);
-  field->initialize();
-  size_t l = 3 * field->numPoints();
-  auto *savedPos = new double[l];
-  size_t i = 0;
-  for (const auto pptr : field->positions()) {
-    for (size_t j = 0; j < 3; ++j) {
-      savedPos[i++] = (*pptr)[j];
-    }
-  }
-  TEST_ASSERT(i == l);
-  e1 = field->calcEnergy();
-  field->minimize(10000, 1.0e-6, 1.0e-3);
-  e2 = field->calcEnergy();
-  TEST_ASSERT(e2 < e1);
-  e3 = field->calcEnergy(savedPos);
-  TEST_ASSERT(feq(e3, e1, 0.01));
-
-  delete[] savedPos;
-  delete mol;
-  delete field;
-
-  BOOST_LOG(rdErrorLog) << "  done" << std::endl;
-}
-
-void testCalcGrad() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "    Testing calcGrad." << std::endl;
-
-  RWMol *mol;
-  ForceFields::ForceField *field;
-
-  std::string pathName = getenv("RDBASE");
-  pathName += "/Code/GraphMol/ForceFieldHelpers/MMFF/test_data";
-  mol = MolFileToMol(pathName + "/Issue239.mol", false);
-  TEST_ASSERT(mol);
-  MolOps::sanitizeMol(*mol);
-
-  field = MMFF::constructForceField(*mol);
-  TEST_ASSERT(field);
-  field->initialize();
-  size_t l = 3 * field->numPoints();
-  auto *savedPos = new double[l];
-  auto *grad1 = new double[l];
-  auto *grad2 = new double[l];
-  size_t i = 0;
-  for (const auto pptr : field->positions()) {
-    for (size_t j = 0; j < 3; ++j) {
-      savedPos[i++] = (*pptr)[j];
-    }
-  }
-  TEST_ASSERT(i == l);
-
-  std::memset(grad1, 0, l * sizeof(double));
-  field->calcGrad(grad1);
-  for (i = 0; i < l; ++i) {
-    TEST_ASSERT(!feq(grad1[i], 0.0, 0.001));
-  }
-
-  field->minimize(10000, 1.0e-6, 1.0e-3);
-  std::memset(grad2, 0, l * sizeof(double));
-  field->calcGrad(grad2);
-  for (i = 0; i < l; ++i) {
-    TEST_ASSERT(feq(grad2[i], 0.0, 0.001));
-  }
-
-  field->initialize();
-  std::memset(grad2, 0, l * sizeof(double));
-  field->calcGrad(savedPos, grad2);
-  for (i = 0; i < l; ++i) {
-    TEST_ASSERT(feq(grad1[i], grad2[i], 0.001));
-  }
-
-  delete[] savedPos;
-  delete[] grad1;
-  delete[] grad2;
-  delete mol;
-  delete field;
-
-  BOOST_LOG(rdErrorLog) << "  done" << std::endl;
-}
-
 void testIssue242() {
   // FIX: Changes to the forcefield (connected to Issue 408) have
   // made it so that this particular problem no longer manifests
@@ -575,7 +442,7 @@ void testIssue242() {
   RWMol *mol, *mol2;
   int needMore;
   (void)needMore;  // add test later
-  ForceFields::ForceField *field = nullptr, *field2 = nullptr;
+  ForceFields::ForceField *field = 0, *field2 = 0;
   std::string mb1, mb2;
   double e1, e2;
 
@@ -631,7 +498,7 @@ void testGithub308() {
   ROMol *mol = SmilesToMol("FF");
   TEST_ASSERT(DGeomHelpers::EmbedMolecule(*mol) >= 0);
   int needMore;
-  ForceFields::ForceField *field = nullptr;
+  ForceFields::ForceField *field = 0;
   TEST_ASSERT(mol);
   MMFF::MMFFMolProperties mmffMolProperties(*mol);
   TEST_ASSERT(mmffMolProperties.isValid());
@@ -640,8 +507,6 @@ void testGithub308() {
   field->initialize();
   needMore = field->minimize(200, 1.0e-6, 1.0e-3);
   TEST_ASSERT(!needMore);
-  delete mol;
-  delete field;
 }
 
 void testSFIssue1653802() {
@@ -662,22 +527,17 @@ void testSFIssue1653802() {
       new MMFF::MMFFMolProperties(*mol);
   TEST_ASSERT(mmffMolProperties);
 
-  boost::shared_array<std::uint8_t> nbrMat;
+  boost::shared_array<boost::uint8_t> nbrMat;
   field = new ForceFields::ForceField();
-  // add the atomic positions:
-  for (unsigned int i = 0; i < mol->getNumAtoms(); ++i) {
-    field->positions().push_back(&((mol->getConformer().getAtomPos(i))));
-  }
-
   MMFF::Tools::addBonds(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 1);
+  TEST_ASSERT(field->contribs().size() == 8);
 
   nbrMat = MMFF::Tools::buildNeighborMatrix(*mol);
   MMFF::Tools::addAngles(*mol, mmffMolProperties, field);
-  TEST_ASSERT(field->contribs().size() == 2);
+  TEST_ASSERT(field->contribs().size() == 20);
   MMFF::Tools::addTorsions(*mol, mmffMolProperties, field);
   // std::cout << field->contribs().size() << std::endl;
-  TEST_ASSERT(field->contribs().size() == 3);
+  TEST_ASSERT(field->contribs().size() == 36);
   MMFF::Tools::addVdW(*mol, 0, mmffMolProperties, field, nbrMat);
   delete field;
 
@@ -756,8 +616,7 @@ void testSFIssue2378119() {
 void testGithub162() {
   BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
   BOOST_LOG(rdErrorLog) << "    Testing github 162: Incorrect SMILES after "
-                           "MMFF parameterization ."
-                        << std::endl;
+                           "MMFF parameterization ." << std::endl;
   {
     ROMol *mol = SmilesToMol("C1=CNC=C1");
     TEST_ASSERT(mol);
@@ -782,7 +641,6 @@ void testMMFFParamGetters() {
     ROMol *mol = SmilesToMol("c1ccccc1CCNN");
     TEST_ASSERT(mol);
     ROMol *molH = MolOps::addHs(*mol);
-    delete mol;
     TEST_ASSERT(molH);
     MMFF::MMFFMolProperties *mmffMolProperties =
         new MMFF::MMFFMolProperties(*molH);
@@ -792,9 +650,10 @@ void testMMFFParamGetters() {
     ForceFields::MMFF::MMFFBond mmffBondStretchParams[2];
     TEST_ASSERT(mmffMolProperties->getMMFFBondStretchParams(
         *molH, 6, 7, bondType, mmffBondStretchParams[0]));
-    TEST_ASSERT((bondType == 0) &&
-                ((int)std::round(mmffBondStretchParams[0].r0 * 1000) == 1508) &&
-                ((int)std::round(mmffBondStretchParams[0].kb * 1000) == 4258));
+    TEST_ASSERT(
+        (bondType == 0) &&
+        ((int)boost::math::round(mmffBondStretchParams[0].r0 * 1000) == 1508) &&
+        ((int)boost::math::round(mmffBondStretchParams[0].kb * 1000) == 4258));
     TEST_ASSERT(!(mmffMolProperties->getMMFFBondStretchParams(
         *molH, 0, 7, bondType, mmffBondStretchParams[0])));
     unsigned int angleType;
@@ -803,8 +662,9 @@ void testMMFFParamGetters() {
         *molH, 6, 7, 8, angleType, mmffAngleBendParams));
     TEST_ASSERT(
         (angleType == 0) &&
-        ((int)std::round(mmffAngleBendParams.theta0 * 1000) == 108290) &&
-        ((int)std::round(mmffAngleBendParams.ka * 1000) == 777));
+        ((int)boost::math::round(mmffAngleBendParams.theta0 * 1000) ==
+         108290) &&
+        ((int)boost::math::round(mmffAngleBendParams.ka * 1000) == 777));
     TEST_ASSERT(!(mmffMolProperties->getMMFFAngleBendParams(
         *molH, 0, 7, 8, angleType, mmffAngleBendParams)));
     unsigned int stretchBendType;
@@ -814,14 +674,15 @@ void testMMFFParamGetters() {
         mmffBondStretchParams, mmffAngleBendParams));
     TEST_ASSERT(
         (stretchBendType == 0) &&
-        ((int)std::round(mmffStretchBendParams.kbaIJK * 1000) == 136) &&
-        ((int)std::round(mmffStretchBendParams.kbaKJI * 1000) == 282) &&
-        ((int)std::round(mmffAngleBendParams.theta0 * 1000) == 108290) &&
-        ((int)std::round(mmffAngleBendParams.ka * 1000) == 777) &&
-        ((int)std::round(mmffBondStretchParams[0].r0 * 1000) == 1508) &&
-        ((int)std::round(mmffBondStretchParams[0].kb * 1000) == 4258) &&
-        ((int)std::round(mmffBondStretchParams[1].r0 * 1000) == 1451) &&
-        ((int)std::round(mmffBondStretchParams[1].kb * 1000) == 5084));
+        ((int)boost::math::round(mmffStretchBendParams.kbaIJK * 1000) == 136) &&
+        ((int)boost::math::round(mmffStretchBendParams.kbaKJI * 1000) == 282) &&
+        ((int)boost::math::round(mmffAngleBendParams.theta0 * 1000) ==
+         108290) &&
+        ((int)boost::math::round(mmffAngleBendParams.ka * 1000) == 777) &&
+        ((int)boost::math::round(mmffBondStretchParams[0].r0 * 1000) == 1508) &&
+        ((int)boost::math::round(mmffBondStretchParams[0].kb * 1000) == 4258) &&
+        ((int)boost::math::round(mmffBondStretchParams[1].r0 * 1000) == 1451) &&
+        ((int)boost::math::round(mmffBondStretchParams[1].kb * 1000) == 5084));
     TEST_ASSERT(!(mmffMolProperties->getMMFFStretchBendParams(
         *molH, 0, 7, 8, stretchBendType, mmffStretchBendParams,
         mmffBondStretchParams, mmffAngleBendParams)));
@@ -829,33 +690,32 @@ void testMMFFParamGetters() {
     ForceFields::MMFF::MMFFTor mmffTorsionParams;
     TEST_ASSERT(mmffMolProperties->getMMFFTorsionParams(
         *molH, 6, 7, 8, 9, torType, mmffTorsionParams));
-    TEST_ASSERT((torType == 0) &&
-                ((int)std::round(mmffTorsionParams.V1 * 1000) == 0) &&
-                ((int)std::round(mmffTorsionParams.V2 * 1000) == -300) &&
-                ((int)std::round(mmffTorsionParams.V3 * 1000) == 500));
+    TEST_ASSERT(
+        (torType == 0) &&
+        ((int)boost::math::round(mmffTorsionParams.V1 * 1000) == 0) &&
+        ((int)boost::math::round(mmffTorsionParams.V2 * 1000) == -300) &&
+        ((int)boost::math::round(mmffTorsionParams.V3 * 1000) == 500));
     TEST_ASSERT(!(mmffMolProperties->getMMFFTorsionParams(
         *molH, 0, 7, 8, 9, torType, mmffTorsionParams)));
     ForceFields::MMFF::MMFFOop mmffOopBendParams;
     TEST_ASSERT(mmffMolProperties->getMMFFOopBendParams(*molH, 6, 5, 4, 0,
                                                         mmffOopBendParams));
-    TEST_ASSERT(((int)std::round(mmffOopBendParams.koop * 1000) == 40));
+    TEST_ASSERT(((int)boost::math::round(mmffOopBendParams.koop * 1000) == 40));
     TEST_ASSERT(!(mmffMolProperties->getMMFFOopBendParams(*molH, 6, 5, 4, 1,
                                                           mmffOopBendParams)));
     ForceFields::MMFF::MMFFVdWRijstarEps mmffVdWParams;
     RWMol *patt = SmartsToMol("NN[H]");
     MatchVectType matchVect;
     TEST_ASSERT(SubstructMatch(*molH, (ROMol &)*patt, matchVect));
-    delete patt;
     unsigned int nIdx = matchVect[0].second;
     unsigned int hIdx = matchVect[2].second;
     TEST_ASSERT(mmffMolProperties->getMMFFVdWParams(nIdx, hIdx, mmffVdWParams));
     TEST_ASSERT(
-        ((int)std::round(mmffVdWParams.R_ij_starUnscaled * 1000) == 3321) &&
-        ((int)std::round(mmffVdWParams.epsilonUnscaled * 1000) == 34) &&
-        ((int)std::round(mmffVdWParams.R_ij_star * 1000) == 2657) &&
-        ((int)std::round(mmffVdWParams.epsilon * 1000) == 17));
-    delete molH;
-    delete mmffMolProperties;
+        ((int)boost::math::round(mmffVdWParams.R_ij_starUnscaled * 1000) ==
+         3321) &&
+        ((int)boost::math::round(mmffVdWParams.epsilonUnscaled * 1000) == 34) &&
+        ((int)boost::math::round(mmffVdWParams.R_ij_star * 1000) == 2657) &&
+        ((int)boost::math::round(mmffVdWParams.epsilon * 1000) == 17));
   }
 }
 #ifdef RDK_TEST_MULTITHREADED
@@ -863,20 +723,18 @@ namespace {
 void runblock_mmff(const std::vector<ROMol *> &mols,
                    const std::vector<double> &energies, unsigned int count,
                    unsigned int idx) {
-  for (unsigned int rep = 0; rep < 100; ++rep) {
+  for (unsigned int rep = 0; rep < 500; ++rep) {
     for (unsigned int i = 0; i < mols.size(); ++i) {
-      if (i % count != idx) {
-        continue;
-      }
+      if (i % count != idx) continue;
       ROMol *mol = mols[i];
-      ForceFields::ForceField *field = nullptr;
-      if (!(rep % 20)) {
+      ForceFields::ForceField *field = 0;
+      if (!(rep % 100)) {
         BOOST_LOG(rdErrorLog) << "Rep: " << rep << " Mol:" << i << std::endl;
       }
       try {
         field = MMFF::constructForceField(*mol);
       } catch (...) {
-        field = nullptr;
+        field = 0;
       }
       TEST_ASSERT(field);
       field->initialize();
@@ -888,9 +746,8 @@ void runblock_mmff(const std::vector<ROMol *> &mols,
     }
   }
 }
-}  // namespace
-#include <thread>
-#include <future>
+}
+#include <boost/thread.hpp>
 void testMMFFMultiThread() {
   BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
   BOOST_LOG(rdErrorLog) << "    Test MMFF multithreading" << std::endl;
@@ -902,15 +759,13 @@ void testMMFFMultiThread() {
   SDMolSupplier suppl(pathName + "/bulk.sdf");
   std::vector<ROMol *> mols;
   while (!suppl.atEnd() && mols.size() < 100) {
-    ROMol *mol = nullptr;
+    ROMol *mol = 0;
     try {
       mol = suppl.next();
     } catch (...) {
       continue;
     }
-    if (!mol) {
-      continue;
-    }
+    if (!mol) continue;
     mols.push_back(mol);
   }
 
@@ -918,11 +773,11 @@ void testMMFFMultiThread() {
   std::vector<double> energies(mols.size(), 0.0);
   for (unsigned int i = 0; i < mols.size(); ++i) {
     ROMol mol(*mols[i]);
-    ForceFields::ForceField *field = nullptr;
+    ForceFields::ForceField *field = 0;
     try {
       field = MMFF::constructForceField(mol);
     } catch (...) {
-      field = nullptr;
+      field = 0;
     }
     TEST_ASSERT(field);
     field->initialize();
@@ -932,23 +787,18 @@ void testMMFFMultiThread() {
     delete field;
   }
 
-  std::vector<std::future<void>> tg;
+  boost::thread_group tg;
 
   std::cerr << "processing" << std::endl;
   unsigned int count = 4;
   for (unsigned int i = 0; i < count; ++i) {
     std::cerr << " launch :" << i << std::endl;
     std::cerr.flush();
-    tg.emplace_back(std::async(std::launch::async, runblock_mmff, mols,
-                               energies, count, i));
-  }
-  for (auto &fut : tg) {
-    fut.get();
+    tg.add_thread(new boost::thread(runblock_mmff, mols, energies, count, i));
   }
+  tg.join_all();
 
-  for (auto *mol : mols) {
-    delete mol;
-  }
+  BOOST_FOREACH (ROMol *mol, mols) { delete mol; }
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
 
@@ -961,11 +811,11 @@ void testMMFFMultiThread2() {
   SDMolSupplier suppl(pathName + "/bulk.sdf");
   ROMol *m = suppl[4];
   TEST_ASSERT(m);
-  auto *om = new ROMol(*m);
-  for (unsigned int i = 0; i < 200; ++i) {
+  ROMol *om = new ROMol(*m);
+  for (unsigned int i = 0; i < 1000; ++i) {
     m->addConformer(new Conformer(m->getConformer()), true);
   }
-  std::vector<std::pair<int, double>> res;
+  std::vector<std::pair<int, double> > res;
 
   MMFF::MMFFOptimizeMolecule(*om);
   MMFF::MMFFOptimizeMoleculeConfs(*m, res, 0);
@@ -990,52 +840,6 @@ void testMMFFMultiThread2() {
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
 
-void testMMFFMultiThread3() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog) << "    Test MMFF multithreading3" << std::endl;
-
-  std::string pathName = getenv("RDBASE");
-  pathName += "/Code/GraphMol/ForceFieldHelpers/UFF/test_data";
-  SDMolSupplier suppl(pathName + "/bulk.sdf");
-  ROMol *m = suppl[4];
-  TEST_ASSERT(m);
-  auto *om = new ROMol(*m);
-  for (unsigned int i = 0; i < 200; ++i) {
-    m->addConformer(new Conformer(m->getConformer()), true);
-  }
-  std::vector<std::pair<int, double>> res;
-
-  ForceFields::ForceField *omField = MMFF::constructForceField(*om);
-  TEST_ASSERT(omField);
-  omField->initialize();
-  ForceFields::ForceField *mField = MMFF::constructForceField(*m);
-  TEST_ASSERT(mField);
-  mField->initialize();
-
-  ForceFieldsHelper::OptimizeMolecule(*omField);
-  ForceFieldsHelper::OptimizeMoleculeConfs(*m, *mField, res, 0);
-  for (unsigned int i = 1; i < res.size(); ++i) {
-    TEST_ASSERT(!res[i].first);
-    TEST_ASSERT(feq(res[i].second, res[0].second, .00001));
-  }
-  for (unsigned int i = 0; i < m->getNumAtoms(); ++i) {
-    RDGeom::Point3D p0 = om->getConformer().getAtomPos(i);
-    RDGeom::Point3D np0 = m->getConformer().getAtomPos(i);
-    TEST_ASSERT(feq(p0.x, np0.x));
-    TEST_ASSERT(feq(p0.y, np0.y));
-    TEST_ASSERT(feq(p0.z, np0.z));
-    np0 =
-        m->getConformer(11).getAtomPos(i);  // pick some random other conformer
-    TEST_ASSERT(feq(p0.x, np0.x));
-    TEST_ASSERT(feq(p0.y, np0.y));
-    TEST_ASSERT(feq(p0.z, np0.z));
-  }
-  delete m;
-  delete om;
-  delete mField;
-  delete omField;
-  BOOST_LOG(rdErrorLog) << "  done" << std::endl;
-}
 #endif
 
 void testGithub224() {
@@ -1068,36 +872,16 @@ void testGithub224() {
   BOOST_LOG(rdErrorLog) << "  done" << std::endl;
 }
 
-void testGithub6728() {
-  BOOST_LOG(rdErrorLog) << "-------------------------------------" << std::endl;
-  BOOST_LOG(rdErrorLog)
-      << "    Testing github6728: crash due to missing stretch-bend params."
-      << std::endl;
-  RWMol *mol = SmilesToMol("CC(C)(C)CO[H-]F");
-  TEST_ASSERT(mol);
-  MolOps::addHs(*mol);
-  TEST_ASSERT(DGeomHelpers::EmbedMolecule(*mol) >= 0);
-  auto field = MMFF::constructForceField(*mol);
-  TEST_ASSERT(field);
-  field->initialize();
-  delete mol;
-  delete field;
-}
-
 //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
 //
 //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
 int main() {
   RDLog::InitLogs();
-  // we get a ton of warnings here about missing Hs... disable them
-  boost::logging::disable_logs("rdApp.warning");
 #if 1
   testMMFFTyper1();
   testMMFFBuilder1();
   testMMFFBuilder2();
   testIssue239();
-  testCalcEnergyPassedCoords();
-  testCalcGrad();
   testIssue242();
   testGithub308();
   testSFIssue1653802();
@@ -1107,10 +891,8 @@ int main() {
 #ifdef RDK_TEST_MULTITHREADED
   testMMFFMultiThread();
   testMMFFMultiThread2();
-  testMMFFMultiThread3();
 #endif
   testGithub162();
 #endif
   testGithub224();
-  testGithub6728();
 }
