@@ -8,14 +8,14 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-#include <RDGeneral/test.h>
 #include <GraphMol/RDKitBase.h>
 #include <GraphMol/MolPickler.h>
 #include <GraphMol/SmilesParse/SmilesParse.h>
 #include <GraphMol/SmilesParse/SmilesWrite.h>
 #include <RDGeneral/RDLog.h>
 
-#include <cstdlib>
+#include <iostream>
+#include <stdlib.h>
 
 using namespace RDKit;
 using namespace std;
@@ -42,6 +42,21 @@ void test1() {
       if (!m) {
         BOOST_LOG(rdErrorLog) << "failure:" << *smilIt << endl;
       }
+#if 0
+      CHECK_INVARIANT(m,"Smiles parse failed:");
+      canonSmi = MolToSmiles(*m);
+      string pickle;
+      MolPickler::pickleMol(*m,pickle);
+      Mol newM(pickle);
+      string trySmi = MolToSmiles(newM);
+      if(canonSmi!=trySmi){
+	BOOST_LOG(rdErrorLog) << "failure:" << *smilIt << endl;
+	BOOST_LOG(rdErrorLog) << canonSmi << endl;
+	BOOST_LOG(rdErrorLog) << " != " << endl;
+	BOOST_LOG(rdErrorLog) << trySmi << endl;
+      }
+      CHECK_INVARIANT(canonSmi==trySmi,(char *)(string("pickling/depickling failed: ")+trySmi).c_str());
+#endif
       delete m;
     }
   }
